/* 
A* -------------------------------------------------------------------
B* This file contains source code for the PyMOL computer program
C* copyright 1998-2000 by Warren Lyford Delano of DeLano Scientific. 
D* -------------------------------------------------------------------
E* It is unlawful to modify or remove this copyright notice.
F* -------------------------------------------------------------------
G* Please see the accompanying LICENSE file for further information. 
H* -------------------------------------------------------------------
I* Additional authors of this source file include:
-* 
-* 
-*
Z* -------------------------------------------------------------------
*/
#ifndef _H_PopUp
#define _H_PopUp

#include"os_python.h"

#include"Block.h"


Block *PopUpNew(PyMOLGlobals *G,int x,int y,int last_x,int last_y,
                int passive, PyObject *list,Block *parent);

#endif
